==> rivendell-1.7.2.zip: rivendell-1.7.2/rdcastmanager/rdcastmanager_nn.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>EditCast</name>
    <message>
        <source>Editing PodCast</source>
        <translation>Redigerer podkast</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Tittel:</translation>
    </message>
    <message>
        <source>Author E-Mail:</source>
        <translation>E-post til forfattaren:</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategori:</translation>
    </message>
    <message>
        <source>Link URL:</source>
        <translation>Lenkjeadresse:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Skildring:</translation>
    </message>
    <message>
        <source>Source Text:</source>
        <translation>Kjeldetekst:</translation>
    </message>
    <message>
        <source>Source URL:</source>
        <translation>Kjeldeadresse:</translation>
    </message>
    <message>
        <source>Comments URL:</source>
        <translation>Kommentaradresse:</translation>
    </message>
    <message>
        <source>Posted At:</source>
        <translation>Lagt inn:</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nei</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>Cast Expires:</source>
        <translation>Podkasten går ut:</translation>
    </message>
    <message>
        <source>Expires At:</source>
        <translation>Går ut:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Vel</translation>
    </message>
    <message>
        <source>Hold</source>
        <translation>Hald</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <source>Posting Status:</source>
        <translation>Postestatus:</translation>
    </message>
    <message>
        <source>Episode
&amp;Report</source>
        <translation>Episode-
&amp;rapport</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>Media Link:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Air Date/Time:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListCasts</name>
    <message>
        <source>Podcast List</source>
        <translation>Podkastliste</translation>
    </message>
    <message>
        <source>Post From
Car&amp;t/Cut</source>
        <translation>Post frå
Korg/Ku&amp;tt</translation>
    </message>
    <message>
        <source>Post From
&amp;File</source>
        <translation>Post frå
&amp;fil</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>R&amp;ediger</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Slett</translation>
    </message>
    <message>
        <source>Subscription
&amp;Report</source>
        <translation>Abonnements&amp;rapport</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <source> </source>
        <translation> </translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Tittel</translation>
    </message>
    <message>
        <source>Origin</source>
        <translation>Opphav</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Går ut</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Lengd</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Skildring</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategori</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Lenkje</translation>
    </message>
    <message>
        <source>&amp;Casts:</source>
        <translation type="obsolete">&amp;Kastar:</translation>
    </message>
    <message>
        <source>Uploading Audio...</source>
        <translation>Lastar opp lyd...</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Framgang</translation>
    </message>
    <message>
        <source>Format Error</source>
        <translation type="obsolete">Formatfeil</translation>
    </message>
    <message>
        <source>Unable to convert audio file!</source>
        <translation type="obsolete">Greidde ikkje koda om lydfila!</translation>
    </message>
    <message>
        <source>Upload Error</source>
        <translation type="obsolete">Opplastingsfeil</translation>
    </message>
    <message>
        <source>Unable to upload audio file!</source>
        <translation type="obsolete">Greidde ikkje lasta opp lydfila!</translation>
    </message>
    <message>
        <source>Delete Podcast</source>
        <translation>Slett podkast</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this podcast?</source>
        <translation>Er du sikker på at du vil sletta denne podkasten?</translation>
    </message>
    <message>
        <source>Deleting Podcast...</source>
        <translation>Slettar podkast...</translation>
    </message>
    <message>
        <source>Internal Error</source>
        <translation>Intern feil</translation>
    </message>
    <message>
        <source>Unable to generate purge command!</source>
        <translation>Greidde ikkje laga tømmekommando!</translation>
    </message>
    <message>
        <source>Remote Error</source>
        <translation>Ekstern feil</translation>
    </message>
    <message>
        <source>Unable to delete remote audio!
Continue deleting cast?</source>
        <translation>Greidde ikkje sletta ekstern lyd!
Vil du halda fram med å sletta podkasten?</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Aldri</translation>
    </message>
    <message>
        <source>File Error</source>
        <translation type="obsolete">Filfeil</translation>
    </message>
    <message>
        <source>File does not exist!</source>
        <translation type="obsolete">Fila finst ikkje!</translation>
    </message>
    <message>
        <source>Cannot open file!</source>
        <translation type="obsolete">Greier ikkje opna fila!</translation>
    </message>
    <message>
        <source>Unsupported file type!</source>
        <translation type="obsolete">Filtypen er ikkje støtta!</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Only Show Unexpired Casts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Only Show Active Casts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Posting Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDCastManager - Host</source>
        <translation>RDCastManager - Vert</translation>
    </message>
    <message>
        <source>User: [Unknown]</source>
        <translation>Brukar: [Ukjend]</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Greier ikkje kopla til</translation>
    </message>
    <message>
        <source>Key Name</source>
        <translation>Lykjelnamn</translation>
    </message>
    <message>
        <source>Feed Name</source>
        <translation>Straumnamn</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Skildring</translation>
    </message>
    <message>
        <source>Casts</source>
        <translation>Kastar</translation>
    </message>
    <message>
        <source>&amp;View
Feed</source>
        <translation>&amp;Sjå
straum</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Brukar</translation>
    </message>
</context>
</TS>

==> rivendell-2.2.0.zip: rivendell-2.2.0/rdcastmanager/rdcastmanager_nn.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>EditCast</name>
    <message>
        <source>Editing PodCast</source>
        <translation>Redigerer podkast</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Tittel:</translation>
    </message>
    <message>
        <source>Author E-Mail:</source>
        <translation>E-post til forfattaren:</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategori:</translation>
    </message>
    <message>
        <source>Link URL:</source>
        <translation>Lenkjeadresse:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Skildring:</translation>
    </message>
    <message>
        <source>Source Text:</source>
        <translation>Kjeldetekst:</translation>
    </message>
    <message>
        <source>Source URL:</source>
        <translation>Kjeldeadresse:</translation>
    </message>
    <message>
        <source>Comments URL:</source>
        <translation>Kommentaradresse:</translation>
    </message>
    <message>
        <source>Posted At:</source>
        <translation>Lagt inn:</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nei</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>Cast Expires:</source>
        <translation>Podkasten går ut:</translation>
    </message>
    <message>
        <source>Expires At:</source>
        <translation type="obsolete">Går ut:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Vel</translation>
    </message>
    <message>
        <source>Hold</source>
        <translation>Hald</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <source>Posting Status:</source>
        <translation>Postestatus:</translation>
    </message>
    <message>
        <source>Episode
&amp;Report</source>
        <translation>Episode-
&amp;rapport</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>Media Link:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Air Date/Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expires On:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListCasts</name>
    <message>
        <source>Podcast List</source>
        <translation>Podkastliste</translation>
    </message>
    <message>
        <source>Post From
Car&amp;t/Cut</source>
        <translation>Post frå
Korg/Ku&amp;tt</translation>
    </message>
    <message>
        <source>Post From
&amp;File</source>
        <translation>Post frå
&amp;fil</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>R&amp;ediger</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Slett</translation>
    </message>
    <message>
        <source>Subscription
&amp;Report</source>
        <translation>Abonnements&amp;rapport</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <source> </source>
        <translation> </translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Tittel</translation>
    </message>
    <message>
        <source>Origin</source>
        <translation>Opphav</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Går ut</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Lengd</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Skildring</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategori</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Lenkje</translation>
    </message>
    <message>
        <source>&amp;Casts:</source>
        <translation type="obsolete">&amp;Kastar:</translation>
    </message>
    <message>
        <source>Uploading Audio...</source>
        <translation>Lastar opp lyd...</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Framgang</translation>
    </message>
    <message>
        <source>Format Error</source>
        <translation type="obsolete">Formatfeil</translation>
    </message>
    <message>
        <source>Unable to convert audio file!</source>
        <translation type="obsolete">Greidde ikkje koda om lydfila!</translation>
    </message>
    <message>
        <source>Upload Error</source>
        <translation type="obsolete">Opplastingsfeil</translation>
    </message>
    <message>
        <source>Unable to upload audio file!</source>
        <translation type="obsolete">Greidde ikkje lasta opp lydfila!</translation>
    </message>
    <message>
        <source>Delete Podcast</source>
        <translation type="unfinished">Slett podkast</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this podcast?</source>
        <translation type="unfinished">Er du sikker på at du vil sletta denne podkasten?</translation>
    </message>
    <message>
        <source>Deleting Podcast...</source>
        <translation type="unfinished">Slettar podkast...</translation>
    </message>
    <message>
        <source>Internal Error</source>
        <translation type="obsolete">Intern feil</translation>
    </message>
    <message>
        <source>Unable to generate purge command!</source>
        <translation type="obsolete">Greidde ikkje laga tømmekommando!</translation>
    </message>
    <message>
        <source>Remote Error</source>
        <translation type="unfinished">Ekstern feil</translation>
    </message>
    <message>
        <source>Unable to delete remote audio!
Continue deleting cast?</source>
        <translation type="obsolete">Greidde ikkje sletta ekstern lyd!
Vil du halda fram med å sletta podkasten?</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Aldri</translation>
    </message>
    <message>
        <source>File Error</source>
        <translation type="obsolete">Filfeil</translation>
    </message>
    <message>
        <source>File does not exist!</source>
        <translation type="obsolete">Fila finst ikkje!</translation>
    </message>
    <message>
        <source>Cannot open file!</source>
        <translation type="obsolete">Greier ikkje opna fila!</translation>
    </message>
    <message>
        <source>Unsupported file type!</source>
        <translation type="obsolete">Filtypen er ikkje støtta!</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Only Show Unexpired Casts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Only Show Active Casts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Posting Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to delete remote audio!
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The server said: &quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue deleting cast?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDCastManager - Host</source>
        <translation>RDCastManager - Vert</translation>
    </message>
    <message>
        <source>User: [Unknown]</source>
        <translation>Brukar: [Ukjend]</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Greier ikkje kopla til</translation>
    </message>
    <message>
        <source>Key Name</source>
        <translation>Lykjelnamn</translation>
    </message>
    <message>
        <source>Feed Name</source>
        <translation>Straumnamn</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Skildring</translation>
    </message>
    <message>
        <source>Casts</source>
        <translation>Kastar</translation>
    </message>
    <message>
        <source>&amp;View
Feed</source>
        <translation>&amp;Sjå
straum</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Brukar</translation>
    </message>
</context>
<context>
    <name>PickReportDates</name>
    <message>
        <source>Select Report Dates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Start Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation type="unfinished">&amp;Vel</translation>
    </message>
    <message>
        <source>&amp;End Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Generate
Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
